==> antd-formcore-0.31.10.tgz: package/es/Forms/show.js <==
import _extends from 'babel-runtime/helpers/extends';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _ from 'lodash';
import React, { Fragment, Component } from 'react';
import { Form, Card, Divider, Table } from 'antd';
import DescriptionList from 'ant-design-pro/lib/DescriptionList';
import RenderField from '../RenderField';

var InnerFormCoreFormsShow = function (_Component) {
  _inherits(InnerFormCoreFormsShow, _Component);

  function InnerFormCoreFormsShow() {
    var _temp, _this, _ret;

    _classCallCheck(this, InnerFormCoreFormsShow);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      loading: true,
      form: {}
    }, _this.fetch = function (props) {
      _this.setState({
        loading: true
      });
      props.fetch(function (data) {
        _this.setState({
          loading: false,
          form: data
        });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  InnerFormCoreFormsShow.prototype.componentDidMount = function componentDidMount() {
    this.fetch(this.props);
  };

  InnerFormCoreFormsShow.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var location = nextProps.location;
    var rawLocation = this.props.location;


    if (location.pathname !== rawLocation.pathname) {
      this.fetch(nextProps);
    }
  };

  InnerFormCoreFormsShow.prototype.render = function render() {
    var _this2 = this;

    var _state = this.state,
        loading = _state.loading,
        form = _state.form;

    var sectionsColumns = [{
      title: 'Name',
      dataIndex: 'Id',
      key: 'Id',
      render: function render(text, row) {
        if (row.SectionOperation) {
          return _this2.props.newSectionLink(row.Id);
        }
        if (row.FieldOperation) {
          return _this2.props.newFieldLink(row.Id, row.SectionId);
        }
        if (row.Title) {
          return _this2.props.sectionLink(row.Id, row.Id, row.Title);
        }
        return _this2.props.fieldLink(row.Id, row.SectionId, row.Id.split('_')[1], row.Label);
      }
    }, {
      title: 'Preview',
      render: function render(text, row) {
        if (row.Label) {
          var y = _extends({}, row);
          y.Label = null;
          return RenderField(y, _this2.props.form, {
            style: { width: '100%', display: 'inline-block' }
          }, _this2.props.renderExtra);
        }
        return null;
      }
    }];
    var sections = !form ? [] : _.filter(form.Sections, function (x) {
      return form.Id === x.FormId;
    }).map(function (x) {
      return _extends({}, x, {
        children: _.filter(form.Fields, function (y) {
          return x.Id === y.SectionId && form.Id === x.FormId;
        }).map(function (y) {
          return _extends({}, y, {
            Id: x.Id + '_' + y.Id
          });
        }).concat([{ Id: x.Id + '_FieldOperation', FieldOperation: true, SectionId: x.Id }])
      });
    }).concat([{ Id: 'SectionOperation', SectionOperation: true }]);
    return React.createElement(
      Card,
      {
        className: 'formcore-card-button-fix',
        title: form.Title ? form.Title : 'Product Offer',
        loading: loading,
        style: { marginBottom: 24 },
        extra: this.props.editFormButton
      },
      form ? React.createElement(
        Fragment,
        null,
        React.createElement(
          DescriptionList,
          { size: 'large', title: 'Introduction', style: { marginBottom: 32 } },
          this.props.formIntroduction(form)
        ),
        React.createElement(Divider, { style: { marginBottom: 32 } }),
        React.createElement(
          'div',
          { className: 'formcore_title' },
          form.Parents && form.Parents.length > 0 ? 'Modifications' : 'Components'
        ),
        React.createElement(Table, {
          fixLeft: false,
          scrollWidth: 350,
          className: 'formcore_formTable',
          style: { marginBottom: 24 },
          pagination: false,
          loading: loading,
          dataSource: sections,
          columns: sectionsColumns,
          rowKey: 'Id',
          expandedRowKeys: sections.map(function (x) {
            return x.Id;
          })
        })
      ) : null
    );
  };

  return InnerFormCoreFormsShow;
}(Component);

var FormCoreFormsShow = Form.create()(InnerFormCoreFormsShow);
export default FormCoreFormsShow;

==> antd-formcore-0.35.3.tgz: package/es/Forms/show.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import _ from 'lodash';
import React, { Fragment, Component } from 'react';
import { Form, Card, Divider, Table } from 'antd';
import DescriptionList from 'ant-design-pro/lib/DescriptionList';
import RenderField from '../RenderField';

var InnerFormCoreFormsShow = function (_Component) {
  _inherits(InnerFormCoreFormsShow, _Component);

  function InnerFormCoreFormsShow() {
    var _temp, _this, _ret;

    _classCallCheck(this, InnerFormCoreFormsShow);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      loading: true,
      form: {}
    }, _this.fetch = function (props) {
      _this.setState({
        loading: true
      });
      props.fetch(function (data) {
        _this.setState({
          loading: false,
          form: data
        });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  InnerFormCoreFormsShow.prototype.componentDidMount = function componentDidMount() {
    this.fetch(this.props);
  };

  InnerFormCoreFormsShow.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var location = nextProps.location;
    var rawLocation = this.props.location;


    if (location.pathname !== rawLocation.pathname) {
      this.fetch(nextProps);
    }
  };

  InnerFormCoreFormsShow.prototype.render = function render() {
    var _this2 = this;

    var _state = this.state,
        loading = _state.loading,
        form = _state.form;

    var sectionsColumns = [{
      title: 'Name',
      dataIndex: 'Id',
      key: 'Id',
      render: function render(text, row) {
        if (row.SectionOperation) {
          return _this2.props.newSectionLink(row.Id);
        }
        if (row.FieldOperation) {
          return _this2.props.newFieldLink(row.Id, row.SectionId);
        }
        if (row.Title) {
          return _this2.props.sectionLink(row.Id, row.Id, row.Title);
        }
        return _this2.props.fieldLink(row.Id, row.SectionId, row.Id.split('_')[1], row.Label);
      }
    }, {
      title: 'Preview',
      render: function render(text, row) {
        if (row.Label) {
          var _RenderField;

          var y = _extends({}, row);
          y.Label = null;
          return RenderField(y, _this2.props.form, (_RenderField = {}, _RenderField[y.Column] = y.DefaultValue, _RenderField), {
            style: { width: '100%', display: 'inline-block' }
          }, _this2.props.renderExtra, { expiredAtType: "fixed" }, { handleExpiredAtTypeChange: function handleExpiredAtTypeChange() {} });
        }
        return null;
      }
    }];
    var sections = !form ? [] : _.filter(form.Sections, function (x) {
      return form.Id === x.FormId;
    }).map(function (x) {
      return _extends({}, x, {
        children: _.filter(form.Fields, function (y) {
          return x.Id === y.SectionId && form.Id === x.FormId;
        }).map(function (y) {
          return _extends({}, y, {
            Id: x.Id + '_' + y.Id
          });
        }).concat([{ Id: x.Id + '_FieldOperation', FieldOperation: true, SectionId: x.Id }])
      });
    }).concat([{ Id: 'SectionOperation', SectionOperation: true }]);
    return React.createElement(
      Card,
      {
        className: 'formcore-card-button-fix',
        title: form.Title ? form.Title : 'Product Offer',
        loading: loading,
        style: { marginBottom: 24 },
        extra: this.props.editFormButton
      },
      form ? React.createElement(
        Fragment,
        null,
        React.createElement(
          DescriptionList,
          { size: 'large', title: 'Introduction', style: { marginBottom: 32 } },
          this.props.formIntroduction(form)
        ),
        React.createElement(Divider, { style: { marginBottom: 32 } }),
        React.createElement(
          'div',
          { className: 'formcore_title' },
          form.Parents && form.Parents.length > 0 ? 'Modifications' : 'Components'
        ),
        React.createElement(Table, {
          fixLeft: false,
          scrollWidth: 350,
          className: 'formcore_formTable',
          style: { marginBottom: 24 },
          pagination: false,
          loading: loading,
          dataSource: sections,
          columns: sectionsColumns,
          rowKey: 'Id',
          expandedRowKeys: sections.map(function (x) {
            return x.Id;
          })
        })
      ) : null
    );
  };

  return InnerFormCoreFormsShow;
}(Component);

var FormCoreFormsShow = Form.create()(InnerFormCoreFormsShow);
export default FormCoreFormsShow;
